@@ -14,7 +14,7 @@ from typing import Any, Dict, List, Optional, Tuple
 import requests
 from dateutil.parser import parse as dateutil_parse
 
-from . import templates_markdown
+from . import templates_markdown, __version__
 
 ENV_GITHUB_TOKEN = "GITHUB_ACCESS_TOKEN"
 GITHUB_ACCESS_TOKEN_PATHS = [
@@ -155,6 +155,9 @@ def parse_args(args):
         action="store",
         dest="file_extension",
     )
+    parser.add_argument(
+        "--version", action="version", version="gh2md {}".format(__version__)
+    )
     return parser.parse_args()
 
 
@@ -345,7 +348,10 @@ class GithubAPI:
         self._session = None  # Requests session
         self._total_pages_fetched = 0
         if not self.token:
-            logger.warning("No token found. Access to private repositories will fail")
+            print(
+                "No Github access token found, exiting. Use gh2md --help so see options for providing a token."
+            )
+            sys.exit(1)
 
         # For testing
         per_page_override = os.environ.get("_GH2MD_PER_PAGE_OVERRIDE", None)
@@ -769,6 +775,7 @@ def format_issue_to_markdown(issue: GithubIssue) -> Tuple[str, str]:
 
 def get_environment_token() -> str:
     try:
+        logger.info(f"Looking for token in envvar {ENV_GITHUB_TOKEN}")
         token = os.environ[ENV_GITHUB_TOKEN]
         logger.info("Using token from environment")
         return token
@@ -794,7 +801,7 @@ def main():
                 )
         else:
             logger.info(f"Creating output directory: {args.output_path}")
-            os.mkdir(args.output_path)
+            os.makedirs(args.output_path, exist_ok=True)
 
     gh = GithubAPI(token=get_environment_token())
     repo = gh.fetch_and_decode_repository(
